.. _beginners-guide-index:

################
Beginner's Guide
################

.. htmlonly::

    :Release: |version|
    :Date: |today|

.. toctree::
    :maxdepth: 2

    pyplot_tutorial.rst
    style_sheets.rst
    navigation_toolbar.rst
    index_text.rst
    image_tutorial.rst
    legend_guide.rst
    annotations_guide.rst
    screenshots.rst
    colormaps.rst



